BatchingDescriptorProto

Struct BatchingDescriptorProto 

#[non_exhaustive]
pub struct BatchingDescriptorProto { pub batched_field: String, pub discriminator_fields: Vec<String>, pub subresponse_field: String, /* private fields */ }
BatchingDescriptorProto specifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
batched_field: String

The repeated field in the request message to be aggregated by batching.

discriminator_fields: Vec<String>

A list of the fields in the request message. Two requests will be batched together only if the values of every field specified in request_discriminator_fields is equal between the two requests.

subresponse_field: String

Optional. When present, indicates the field in the response message to be used to demultiplex the response into multiple response messages, in correspondence with the multiple request messages originally batched together.

Implementations

Source

impl BatchingDescriptorProto

pub fn new() -> Self

pub fn set_batched_field<T: Into<String>>(self, v: T) -> Self

Sets the value of batched_field.

Example
let x = BatchingDescriptorProto::new().set_batched_field("example");
pub fn set_discriminator_fields<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of discriminator_fields.

Example
let x = BatchingDescriptorProto::new().set_discriminator_fields(["a", "b", "c"]);
pub fn set_subresponse_field<T: Into<String>>(self, v: T) -> Self

Sets the value of subresponse_field.

Example
let x = BatchingDescriptorProto::new().set_subresponse_field("example");