#[non_exhaustive]pub struct MethodSettings {
pub selector: String,
pub long_running: Option<LongRunning>,
pub auto_populated_fields: Vec<String>,
pub batching: Option<BatchingConfigProto>,
/* private fields */
}Expand description
Describes the generator configuration for a method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.selector: StringThe fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
Example:
publishing:
method_settings:
- selector: google.storage.control.v2.StorageControl.CreateFolder
# method settings for CreateFolder...long_running: Option<LongRunning>Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto.
Example of a YAML configuration::
publishing:
method_settings:
- selector: google.cloud.speech.v2.Speech.BatchRecognize
long_running:
initial_poll_delay: 60s # 1 minute
poll_delay_multiplier: 1.5
max_poll_delay: 360s # 6 minutes
total_poll_timeout: 54000s # 90 minutesauto_populated_fields: Vec<String>List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.
Example of a YAML configuration:
publishing:
method_settings:
- selector: google.example.v1.ExampleService.CreateExample
auto_populated_fields:
- request_idbatching: Option<BatchingConfigProto>Batching configuration for an API method in client libraries.
Example of a YAML configuration:
publishing:
method_settings:
- selector: google.example.v1.ExampleService.BatchCreateExample
batching:
element_count_threshold: 1000
request_byte_threshold: 100000000
delay_threshold_millis: 10Implementations
Sourceimpl MethodSettings
impl MethodSettings
pub fn new() -> Self
Sourcepub fn set_selector<T: Into<String>>(self, v: T) -> Self
pub fn set_selector<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_long_running<T>(self, v: T) -> Selfwhere
T: Into<LongRunning>,
pub fn set_long_running<T>(self, v: T) -> Selfwhere
T: Into<LongRunning>,
Sets the value of long_running.
Example
use google_cloud_api::model::method_settings::LongRunning;
let x = MethodSettings::new().set_long_running(LongRunning::default()/* use setters */);Sourcepub fn set_or_clear_long_running<T>(self, v: Option<T>) -> Selfwhere
T: Into<LongRunning>,
pub fn set_or_clear_long_running<T>(self, v: Option<T>) -> Selfwhere
T: Into<LongRunning>,
Sets or clears the value of long_running.
Example
use google_cloud_api::model::method_settings::LongRunning;
let x = MethodSettings::new().set_or_clear_long_running(Some(LongRunning::default()/* use setters */));
let x = MethodSettings::new().set_or_clear_long_running(None::<LongRunning>);Sourcepub fn set_auto_populated_fields<T, V>(self, v: T) -> Self
pub fn set_auto_populated_fields<T, V>(self, v: T) -> Self
Sets the value of auto_populated_fields.
Example
let x = MethodSettings::new().set_auto_populated_fields(["a", "b", "c"]);Sourcepub fn set_batching<T>(self, v: T) -> Selfwhere
T: Into<BatchingConfigProto>,
pub fn set_batching<T>(self, v: T) -> Selfwhere
T: Into<BatchingConfigProto>,
Sourcepub fn set_or_clear_batching<T>(self, v: Option<T>) -> Selfwhere
T: Into<BatchingConfigProto>,
pub fn set_or_clear_batching<T>(self, v: Option<T>) -> Selfwhere
T: Into<BatchingConfigProto>,